|Travis|_ |Coveralls|_ |pypi_version|_  |doi|_

.. |Travis| image:: https://travis-ci.org/pyxem/orix.svg?branch=master
.. _Travis: https://travis-ci.org/pyxem/orix

.. |Coveralls| image:: https://coveralls.io/repos/github/pyxem/orix/badge.svg?branch=master
.. _Coveralls: https://coveralls.io/github/pyxem/orix?branch=master

.. |pypi_version| image:: http://img.shields.io/pypi/v/orix.svg?style=flat
.. _pypi_version: https://pypi.python.org/pypi/orix

.. |doi| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.3459662.svg
.. _doi: https://doi.org/10.5281/zenodo.3459662

orix is an open-source python library for analysing orientations and crystal symmetry.

The package defines objects and functions for the analysis of orientations represented as quaternions or 3D rotation vectors accounting for crystal symmetry. Functionality builds primarily on top of `numpy <http://www.numpy.org/>`__ and
`matplotlib <https://matplotlib.org/>`__ and is heavily inspired by the `MATLAB <https://www.mathworks.com/products/matlab.html>`__ package `MTEX <http://mtex-toolbox.github.io/>`__.

If analysis using orix forms a part of published work please cite the github repository.

orix is released under the GPL v3 license.

